@@ -2,11 +2,11 @@ library(epos)
 context("test_filterApprovedDrugs")
 
 test_that("Test function filterApprovedDrugs()", {
-  utils::data(rawDrugBankCoOcEpSO, package="epos")
+  utils::data(rawDrugNamesCoOcEpSO, package="epos")
   atchashda <-
     readAtcMapIntoHashMapDrugNamesAtcCodes(
     system.file("extdata", "db-atc.map", package = "epos"), "\t")
-  tepso <- genDictListFromRawFreq(rawDrugBankCoOcEpSO)
+  tepso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
   fepso <- filterApprovedDrugs(tepso, atchashda)
-  expect_that(length(fepso), equals(1614))
+  expect_that(length(fepso), equals(2313))
 })
\ No newline at end of file
