@@ -2,11 +2,11 @@ library(epos)
 context("test_filterNeuroDrugs")
 
 test_that("Test function filterNeuroDrugs()", {
-  utils::data(rawDrugBankCoOcEpSO, package="epos")
+  utils::data(rawDrugNamesCoOcEpSO, package="epos")
   atchashda <-
     readAtcMapIntoHashMapDrugNamesAtcCodes(
     system.file("extdata", "db-atc.map", package = "epos"), "\t")
-  tepso <- genDictListFromRawFreq(rawDrugBankCoOcEpSO)
+  tepso <- genDictListFromRawFreq(rawDrugNamesCoOcEpSO)
   nepso <- filterNeuroDrugs(tepso, atchashda)
-  expect_that(length(nepso), equals(266))
+  expect_that(length(nepso), equals(360))
 })
\ No newline at end of file
